@@ -1016,8 +1016,11 @@ class Builder(Update):
         :return:
         """
         chroot_path = self.clVars.Get('cl_builder_path')
-        os.system('/usr/bin/chroot %s /usr/sbin/emaint binhost -f &>/dev/null' %
-                  chroot_path)
+        pkgdir = self.clVars.Get('cl_builder_pkgdir_full')
+        os.system(
+            '/usr/bin/chroot %s /bin/bash -c '
+            '"PKGDIR=%s /usr/sbin/emaint binhost -f &>/dev/null' %
+            (chroot_path, pkgdir))
 
     def cleanpkg(self):
         """
@@ -1562,11 +1565,6 @@ class Builder(Update):
         env_update = {'PKGDIR': self.clVars.Get('cl_builder_pkgdir_full')}
         if self.clVars.GetBool('cl_builder_binhost_base_set'):
             env_update["FEATURES"] = "-getbinpkg"
-            # удалить Packages файл, для того, чтобы он переформировался при
-            # следующем вызове emerge
-            index_fn = path.join(env_update['PKGDIR'], "Packages")
-            if path.exists(index_fn):
-                os.unlink(index_fn)
 
         with EmergeParser(self.chrootize(builder_path, EmergeCommand(
                         ["=%s" % x for x in packages] + ["@system"],
@@ -1625,6 +1623,14 @@ class Builder(Update):
             check_data = {x: y for x, y in get_check_data()
                           if x["CATEGORY"] != "virtual"}
 
+            if self.clVars.GetBool('cl_builder_binhost_base_set'):
+                pkgdir = self.clVars.Get('cl_builder_pkgdir_full')
+                # удалить Packages файл, для того, чтобы он переформировался при
+                # следующем вызове emerge
+                index_fn = path.join(pkgdir, "Packages")
+                if path.exists(index_fn):
+                    os.unlink(index_fn)
+
             for i, data in enumerate(sorted(check_data.items(),
                                             key=lambda x:x[0])):
                 package, required_pkgs = data
